open Bigarray

class rng fname = object (self)
  val filename = String.copy fname
  val dat = Array1.create Bigarray.int32 c_layout 128
  val mutable pos = -1
  method min = Int32.zero
  method max = Int32.max_int
  method private fill_buffer =
    let len = 4 * 128 in
    let i = Unix.openfile filename [ Unix.O_RDONLY ] 0
    and buf = String.create len
    and ofname = Filename.temp_file "file_rand" "tmp" in
    let o = Unix.openfile ofname [ Unix.O_RDWR; Unix.O_CREAT ] 0 in
      Unix.unlink ofname;
      let r = Unix.read i buf 0 len in
        if r != len then
          raise (Failure
                   "Couldn't read the required amount of bytes from file");
        Unix.close i;
        let w = Unix.write o buf 0 r in
          if w != len then
            raise (Failure
                     "Couldn't write the required amount of bytes to temp file");
          let _ = Unix.lseek o 0 Unix.SEEK_SET 
          and t = Array1.map_file o Bigarray.int32 c_layout false 128 in
            Array1.blit t dat;
            Unix.close o;
            pos <- 0

  method genrand =
    if pos = -1 or pos >= 128 then
      self#fill_buffer;
    let r = Array1.get dat pos in
      pos <- pos + 1;
      Int32.abs r
end

module type FILE = sig
  val name: string
end

module Dev_Urandom = struct
  let name = "/dev/urandom"
end

module Int32Source (File : FILE) = struct
  type t = int32
  let src = new rng File.name
  let min = src#min
  let max = src#max
  let genrand () = src#genrand
end
            
module IntSource (File: FILE) = struct
  type t = int
  let src = new rng File.name
  let min = 0
  let max = max_int
  let genrand () = 
    let r = src#genrand in
      Int32.to_int (Int32.shift_right_logical r 2)
end

        
