(* string  utility routines for ocaml
   Copyright (C) 2002 Shawn Wagner <raevnos@pennmush.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.
	 
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.
	 
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*)

module String = StdLabels.String

(* Returns the string minus trailing whitespace *)
let chomp str =
  let c = ref true in
  let p = ref ((String.length str)) in
    while !c do
      if !p <= 0 then begin
        p := 0; c := false; end
      else begin
        if CharExtras.is_space (String.get str (!p - 1)) then decr p
        else c := false end
    done;
    String.sub str ~pos:0 ~len:!p
      

(* Returns the first word of a string *)
let first_word str =
	try
		let len = String.index_from str 1 ' ' in
		  String.sub str ~pos:0 ~len
	with
		  Not_found -> str

(* Returns everything after the character. *)
let split_at ~str ~sep  =
	try
		let p = String.index str sep in
		let len = String.length str - p - 1 
		and pos = succ p in
		  String.sub str ~pos ~len
	with
		  Not_found -> ""

(* Cuts off the first character of a string and returns the rest *)
let cut_first_char str =
	let slen = String.length str in
	let len = pred slen in 
	  String.sub str ~pos:1 ~len

(* Cuts off the last character of a string and returns the rest *)
let cut_last_char str = 
	let len = String.length str - 1 in
	  String.sub str ~pos:0 ~len

(* Cuts off the first word of a string and returns the rest *)
let rec cut_first_word str =
	let rest = split_at ~str ~sep:' ' in
	  try
		  let rest_cut = cut_first_char rest in 
		    if String.sub rest ~pos:0 ~len:1 = " " then
			    cut_first_word rest_cut
		    else
			    rest
	  with
		    Not_found -> rest

(* Concatenates a list of strings with a null seperator *)
let combine lst =
	String.concat ~sep:"" lst


(* Return str minus the first n characters *)
let cut_first_n str n =
  let len = String.length str in
    if n > len then
      ""
    else
      String.sub str n (len - n)

(* Return str minus the last n characters *)
let cut_last_n str n = 
  let len = String.length str in
    if n > len then
      ""
    else
      String.sub str 0 (len - n)


