(* Unix extension routines for ocaml
   Copyright (C) 2002 Shawn Wagner <raevnos@pennmush.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.
   
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.
   
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*)

(* Runs f in a new daemon process. The calling process will exit
 * if the second argument is true.
 *
 * For example:
 * [let _ = UnixExtras.make_daemon server_func true]
 * will start a new process and run [server_func] in it, while the original
 * process will exit. See Stevens, Advanced Programming in the Unix Environment
 * for details.
 *)

val make_daemon: (unit -> unit) -> bool -> unit

(* Reads [len] bytes from the [src] descr with offset [start] and
copies them to the [dest] descr. Currently implemented only for Linux
and FreeBSD. The FreeBSD sendfile() system call requires that [dest] be
a socket.

Raises a [Unix_error] on failure.

 *)

external send_file: src:Unix.file_descr -> dest:Unix.file_descr -> start:int -> len:int -> int = "stew_sendfile"


(* More servent functions not provided by the \textbf{Unix}
 * module. They do the same thing as the C versions. *)

external getservent: unit -> Unix.service_entry = "stew_getservent"
external setservent: bool -> unit = "stew_setservent"
external endservent: unit -> unit = "stew_endservent"
